@@ -4,7 +4,6 @@ from typing import List, Dict, Optional, TYPE_CHECKING
 
 from pyknp import Argument as PyknpArgument
 from pyknp import Morpheme, Tag
-from pyknp.knp.pas import Argument
 
 from pyknp_eventgraph.builder import Builder
 from pyknp_eventgraph.component import Component
@@ -106,8 +105,7 @@ class Argument(Component):
                 head_reps = self.head_token.tag.head_prime_repname or self.head_token.tag.head_repname
                 if head_reps:
                     self._head_reps = f'[{head_reps}]' if self.head_token.omitted_case else head_reps
-            else:
-                self._head_reps = self.normalized_reps
+            self._head_reps = self._head_reps or self.normalized_reps
         return self._head_reps
 
     @property
@@ -240,7 +238,7 @@ class Argument(Component):
 
     def to_string(self) -> str:
         """Convert this object into a string."""
-        return f'Argument(case: {self.case}, surf: {self.surf})'
+        return f'<Argument, case: {self.case}, surf: {self.surf}>'
 
 
 class ArgumentBuilder(Builder):
